@@ -24,7 +24,6 @@ DEFAULT_CONFIG = {
     "FALKORDB_PATH": str(CONFIG_DIR / "falkordb.db"),
     "FALKORDB_SOCKET_PATH": str(CONFIG_DIR / "falkordb.sock"),
     "INDEX_VARIABLES": "true",
-    "INDEX_PARAMETERS": "true",
     "ALLOW_DB_DELETION": "false",
     "DEBUG_LOGS": "false",
     "DEBUG_LOG_PATH": str(Path.home() / "mcp_debug.log"),
@@ -47,7 +46,6 @@ CONFIG_DESCRIPTIONS = {
     "FALKORDB_PATH": "Path to FalkorDB database file",
     "FALKORDB_SOCKET_PATH": "Path to FalkorDB Unix socket",
     "INDEX_VARIABLES": "Index variable nodes in the graph (lighter graph if false)",
-    "INDEX_PARAMETERS": "Index parameter nodes in the graph (lighter graph if false)",
     "ALLOW_DB_DELETION": "Allow full database deletion commands",
     "DEBUG_LOGS": "Enable debug logging (for development/troubleshooting)",
     "DEBUG_LOG_PATH": "Path to debug log file",
@@ -68,7 +66,6 @@ CONFIG_DESCRIPTIONS = {
 CONFIG_VALIDATORS = {
     "DEFAULT_DATABASE": ["neo4j", "falkordb"],
     "INDEX_VARIABLES": ["true", "false"],
-    "INDEX_PARAMETERS": ["true", "false"],
     "ALLOW_DB_DELETION": ["true", "false"],
     "DEBUG_LOGS": ["true", "false"],
     "ENABLE_APP_LOGS": ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL", "DISABLED"],
@@ -318,8 +315,29 @@ def reset_config():
     console.print("[cyan]Note: Database credentials were preserved[/cyan]")
 
 
+
+def ensure_config_file():
+    """
+    Create default .env config file on first run if it does not exist.
+    """
+    ensure_config_dir()
+
+    if CONFIG_FILE.exists():
+        return False  # file already exists
+
+    save_config(DEFAULT_CONFIG.copy(), preserve_db_credentials=False)
+    return True  # file was created
+
+
+
+
 def show_config():
     """Display current configuration in a nice table."""
+    created = ensure_config_file()
+    if created:
+        console.print(
+            f"[green]🆕 Created default configuration at {CONFIG_FILE}[/green]\n"
+        )
     config = load_config()
     
     # Separate database credentials from configuration
